@@ -18,9 +18,10 @@ from hbshare.base.data_pro import (hb_api)
 from hbshare.base.upass import (get_token, set_token)
 
 from hbshare.quant.load_data import (load_calendar_extra, load_funds_data, load_funds_alpha)
-# from hbshare.quant.gen_charts import (nav_lines, gen_grid)
+from hbshare.quant.gen_charts import (nav_lines, gen_grid)
 
 from hbshare.loader.data_query import (db_data_query)
+
 from hbshare.simu.simu_index import (simu_index, SimuIndex)
 
 
